@@ -22,17 +22,19 @@
 
 #include "config.h"
 
-#include <gtk/gtk.h>
 #include <gdk/gdk.h>
 
 #define GNOME_DESKTOP_USE_UNSTABLE_API
 #include <libgnome-desktop/gnome-rr.h>
 
 #include "gsd-input-helper.h"
-#include "gnome-settings-plugin.h"
 #include "gnome-settings-profile.h"
 #include "gsd-orientation-manager.h"
 
+#define GSD_DBUS_NAME "org.gnome.SettingsDaemon"
+#define GSD_DBUS_PATH "/org/gnome/SettingsDaemon"
+#define GSD_DBUS_BASE_INTERFACE "org.gnome.SettingsDaemon"
+
 typedef enum {
         ORIENTATION_UNDEFINED,
         ORIENTATION_NORMAL,
